@@ -21,7 +21,7 @@ if platform.system() == "Windows":
         if "PATH" in os.environ:
             for p in os.environ["PATH"].split(os.pathsep):
                 if p and glob.glob(os.path.join(p, "gdal*.dll")):
-                    os.add_dll_directory(p)
+                    os.add_dll_directory(os.path.abspath(p))
 
 
 from rasterio._show_versions import show_versions
@@ -81,7 +81,7 @@ except ImportError:
     have_vsi_plugin = False
 
 __all__ = ['band', 'open', 'pad', 'Env', 'CRS']
-__version__ = "1.3.4"
+__version__ = "1.3.5"
 __gdal_version__ = gdal_version()
 __proj_version__ = ".".join([str(version) for version in get_proj_version()])
 __geos_version__ = ".".join([str(version) for version in get_geos_version()])
