@@ -41,7 +41,7 @@ class FileOverwriteError(FileError):
         super().__init__('', hint=message)
 
 
-class RasterioIOError(IOError):
+class RasterioIOError(OSError):
     """Raised when a dataset cannot be opened using one of the
     registered format drivers."""
 
@@ -59,8 +59,11 @@ class NotGeoreferencedWarning(UserWarning):
     """Warn that a dataset isn't georeferenced."""
 
 
-class RPCTransformWarning(UserWarning):
-    """Error raised when GDALRPCTransform fails."""
+class TransformWarning(UserWarning):
+    """Warn that coordinate transformations may behave unexpectedly"""
+
+class RPCError(ValueError):
+    """Raised when RPC transformation is invalid"""
 
 
 class ShapeSkipWarning(UserWarning):
@@ -73,6 +76,11 @@ class GDALBehaviorChangeException(RuntimeError):
     expecting it to be off will be presented with a MultiPolygon when the
     rest of their code expects a Polygon.
 
+    Examples
+    --------
+
+    .. code-block:: python
+
         # Raises an exception on GDAL >= 2.2.0
         rasterio.warp.transform_geometry(
             src_crs, dst_crs, antimeridian_cutting=False)
