@@ -1,6 +1,5 @@
 """Functions for working with features in a raster dataset."""
 
-
 import logging
 import math
 import os
@@ -9,9 +8,14 @@ import warnings
 import numpy as np
 
 import rasterio
-from rasterio.dtypes import validate_dtype, can_cast_dtype, get_minimum_dtype, _getnpdtype
+from rasterio.dtypes import (
+    validate_dtype,
+    can_cast_dtype,
+    get_minimum_dtype,
+    _getnpdtype,
+)
 from rasterio.enums import MergeAlg
-from rasterio.env import ensure_env
+from rasterio.env import ensure_env, GDALVersion
 from rasterio.errors import ShapeSkipWarning
 from rasterio._features import _shapes, _sieve, _rasterize, _bounds
 from rasterio import warp
@@ -191,11 +195,11 @@ def rasterize(
 
     Parameters
     ----------
-    shapes : iterable of (`geometry`, `value`) pairs or iterable over
-        geometries. The `geometry` can either be an object that
-        implements the geo interface or GeoJSON-like object. If no
-        `value` is provided the `default_value` will be used. If `value`
-        is `None` the `fill` value will be used.
+    shapes : iterable of (`geometry`, `value`) pairs or geometries
+        The `geometry` can either be an object that implements the geo
+        interface or GeoJSON-like object. If no `value` is provided
+        the `default_value` will be used. If `value` is `None` the
+        `fill` value will be used.
     out_shape : tuple or list with 2 integers
         Shape of output numpy ndarray.
     fill : int or float, optional
@@ -251,6 +255,8 @@ def rasterize(
     valid_dtypes = (
         'int16', 'int32', 'uint8', 'uint16', 'uint32', 'float32', 'float64'
     )
+    if GDALVersion.runtime().at_least("3.5"):
+        valid_dtypes = valid_dtypes + ("int64", "uint64")
 
     def format_invalid_dtype(param):
         return '{0} dtype must be one of: {1}'.format(
@@ -299,7 +305,7 @@ def rasterize(
             if geom_type == 'GeometryCollection':
                 # GeometryCollections need to be handled as individual parts to
                 # avoid holes in output:
-                # https://github.com/mapbox/rasterio/issues/1253.
+                # https://github.com/rasterio/rasterio/issues/1253.
                 # Only 1-level deep since GeoJSON spec discourages nested
                 # GeometryCollections
                 for part in geom['geometries']:
