@@ -74,15 +74,19 @@ def show(source, with_bounds=True, contour=False, contour_label_kws=None,
     -------
     ax : matplotlib Axes
         Axes with plot.
+
     """
     plt = get_plt()
 
     if isinstance(source, tuple):
         arr = source[0].read(source[1])
+
         if len(arr.shape) >= 3:
             arr = reshape_as_image(arr)
+
         if with_bounds:
             kwargs['extent'] = plotting_extent(source[0])
+
     elif isinstance(source, DatasetReader):
         if with_bounds:
             kwargs['extent'] = plotting_extent(source)
@@ -91,19 +95,20 @@ def show(source, with_bounds=True, contour=False, contour_label_kws=None,
             arr = source.read(1, masked=True)
         else:
             try:
-
-                # Lookup table for the color space in the source file. This will allow us to re-order it
-                # to RGB if needed
+                # Lookup table for the color space in the source file.
+                # This will allow us to re-order it to RGB if needed
                 source_colorinterp = OrderedDict(zip(source.colorinterp, source.indexes))
-
                 colorinterp = rasterio.enums.ColorInterp
 
                 # Gather the indexes of the RGB channels in that order
-                rgb_indexes = [source_colorinterp[ci] for ci in
-                               (colorinterp.red, colorinterp.green, colorinterp.blue)]
+                rgb_indexes = [
+                    source_colorinterp[ci]
+                    for ci in (colorinterp.red, colorinterp.green, colorinterp.blue)
+                ]
 
-                # Read the image in the proper order so the numpy array will have the colors in the
-                # order expected by matplotlib (RGB)
+                # Read the image in the proper order so the numpy array
+                # will have the colors in the order expected by
+                # matplotlib (RGB)
                 arr = source.read(rgb_indexes, masked=True)
                 arr = reshape_as_image(arr)
 
@@ -112,20 +117,26 @@ def show(source, with_bounds=True, contour=False, contour_label_kws=None,
     else:
         # The source is a numpy array reshape it to image if it has 3+ bands
         source = np.ma.squeeze(source)
+
         if len(source.shape) >= 3:
             arr = reshape_as_image(source)
         else:
             arr = source
+
         if transform and with_bounds:
             kwargs['extent'] = plotting_extent(arr, transform)
+
     if adjust and arr.ndim >= 3:
         # Adjust each band by the min/max so it will plot as RGB.
-        arr = reshape_as_raster(arr)
+        arr = reshape_as_raster(arr).astype("float64")
+
         for ii, band in enumerate(arr):
-            arr[ii] = adjust_band(band, kind='linear')
+            arr[ii] = adjust_band(band)
+
         arr = reshape_as_image(arr)
 
     show = False
+
     if not ax:
         show = True
         ax = plt.gca()
@@ -133,18 +144,21 @@ def show(source, with_bounds=True, contour=False, contour_label_kws=None,
     if contour:
         if 'cmap' not in kwargs:
             kwargs['colors'] = kwargs.get('colors', 'red')
+
         kwargs['linewidths'] = kwargs.get('linewidths', 1.5)
         kwargs['alpha'] = kwargs.get('alpha', 0.8)
 
         C = ax.contour(arr, origin='upper', **kwargs)
+
         if contour_label_kws is None:
             # no explicit label kws passed use defaults
-            contour_label_kws = dict(fontsize=8,
-                                     inline=True)
+            contour_label_kws = dict(fontsize=8, inline=True)
+
         if contour_label_kws:
             ax.clabel(C, **contour_label_kws)
     else:
         ax.imshow(arr, **kwargs)
+
     if title:
         ax.set_title(title, fontweight='bold')
 
@@ -310,26 +324,22 @@ def show_hist(source, bins=10, masked=True, title='Histogram', ax=None, label=No
         plt.show()
 
 
-def adjust_band(band, kind='linear'):
+def adjust_band(band, kind=None):
     """Adjust a band to be between 0 and 1.
 
     Parameters
     ----------
     band : array, shape (height, width)
         A band of a raster object.
-    kind : 'linear'
-        The kind of normalization to apply. For now, there
-        is only one option ('linear').
+    kind : str
+        An unused option. For now, there is only one option ('linear').
 
     Returns
     -------
     band_normed : array, shape (height, width)
         An adjusted version of the input band.
+
     """
-    band_normed = np.zeros_like(band)
-    if kind == 'linear':
-        # Including this `if` statement in case future norms are added.
-        imin = np.nanmin(band)
-        imax = np.nanmax(band)
-        band_normed = (band - imin) / (imax - imin)
-    return band_normed
+    imin = np.float64(np.nanmin(band))
+    imax = np.float64(np.nanmax(band))
+    return (band - imin) / (imax - imin)
