@@ -17,7 +17,7 @@ from rasterio.warp import transform_bounds
 logger = logging.getLogger(__name__)
 
 
-class _Collection(object):
+class _Collection:
 
     """For use with `rasterio.rio.helpers.write_features()`."""
 
@@ -96,9 +96,8 @@ class _Collection(object):
     help="Index of the band that is the source of shapes.")
 @click.pass_context
 def blocks(
-        ctx, input, output, precision, indent, compact, projection, sequence,
-        use_rs, bidx):
-
+    ctx, input, output, precision, indent, compact, projection, sequence, use_rs, bidx
+):
     """Write dataset blocks as GeoJSON features.
 
     This command writes features describing a raster's internal blocks, which
@@ -131,8 +130,8 @@ def blocks(
 
     For more information on exactly what blocks and windows represent, see
     'dataset.block_windows()'.
-    """
 
+    """
     dump_kwds = {'sort_keys': True}
 
     if indent:
@@ -152,11 +151,13 @@ def blocks(
             dataset=src,
             bidx=bidx,
             precision=precision,
-            geographic=projection != 'projected')
-
+            geographic=projection != "projected",
+        )
         write_features(
-            stdout, collection,
+            stdout,
+            collection,
             sequence=sequence,
-            geojson_type='feature' if sequence else 'collection',
+            geojson_type="feature" if sequence else "collection",
             use_rs=use_rs,
-            **dump_kwds)
+            **dump_kwds
+        )
