@@ -1,46 +1,48 @@
 """
 Registry of common rio CLI options.  See cligj for more options.
 
--a, --all: Use all pixels touched by features.  In rio-mask, rio-rasterize
---as-mask/--not-as-mask: interpret band as mask or not.  In rio-shapes
---band/--mask: use band or mask.  In rio-shapes
---bbox:
--b, --bidx: band index(es) (singular or multiple value versions).
-    In rio-info, rio-sample, rio-shapes, rio-stack (different usages)
---bounds: bounds in world coordinates.
-    In rio-info, rio-rasterize (different usages)
---count: count of bands.  In rio-info
---crop: Crop raster to extent of features.  In rio-mask
---crs: CRS of input raster.  In rio-info
---default-value: default for rasterized pixels.  In rio-rasterize
---dimensions: Output width, height.  In rio-rasterize
---dst-crs: destination CRS.  In rio-transform
---fill: fill value for pixels not covered by features.  In rio-rasterize
---formats: list available formats.  In rio-info
---height: height of raster.  In rio-info
--i, --invert: Invert mask created from features: In rio-mask
--j, --geojson-mask: GeoJSON for masking raster.  In rio-mask
---lnglat: geograhpic coordinates of center of raster.  In rio-info
---masked/--not-masked: read masked data from source file.
-    In rio-calc, rio-info
--m, --mode: output file mode (r, r+).  In rio-insp
---name: input file name alias.  In rio-calc
---nodata: nodata value.  In rio-info, rio-merge (different usages)
---photometric: photometric interpretation.  In rio-stack
---property: GeoJSON property to use as values for rasterize.  In rio-rasterize
--r, --res: output resolution.
-    In rio-info, rio-rasterize (different usages.  TODO: try to combine
-    usages, prefer rio-rasterize version)
---sampling: Inverse of sampling fraction.  In rio-shapes
---shape: shape (width, height) of band.  In rio-info
---src-crs: source CRS.
-    In rio-insp, rio-rasterize (different usages.  TODO: consolidate usages)
---stats: print raster stats.  In rio-inf
--t, --dtype: data type.  In rio-calc, rio-info (different usages)
---width: width of raster.  In rio-info
---with-nodata/--without-nodata: include nodata regions or not.  In rio-shapes.
--v, --tell-me-more, --verbose
---vfs: virtual file system.
+.. code-block:: none
+
+    -a, --all: Use all pixels touched by features.  In rio-mask, rio-rasterize
+    --as-mask/--not-as-mask: interpret band as mask or not.  In rio-shapes
+    --band/--mask: use band or mask.  In rio-shapes
+    --bbox:
+    -b, --bidx: band index(es) (singular or multiple value versions).
+        In rio-info, rio-sample, rio-shapes, rio-stack (different usages)
+    --bounds: bounds in world coordinates.
+        In rio-info, rio-rasterize (different usages)
+    --count: count of bands.  In rio-info
+    --crop: Crop raster to extent of features.  In rio-mask
+    --crs: CRS of input raster.  In rio-info
+    --default-value: default for rasterized pixels.  In rio-rasterize
+    --dimensions: Output width, height.  In rio-rasterize
+    --dst-crs: destination CRS.  In rio-transform
+    --fill: fill value for pixels not covered by features.  In rio-rasterize
+    --formats: list available formats.  In rio-info
+    --height: height of raster.  In rio-info
+    -i, --invert: Invert mask created from features: In rio-mask
+    -j, --geojson-mask: GeoJSON for masking raster.  In rio-mask
+    --lnglat: geograhpic coordinates of center of raster.  In rio-info
+    --masked/--not-masked: read masked data from source file.
+        In rio-calc, rio-info
+    -m, --mode: output file mode (r, r+).  In rio-insp
+    --name: input file name alias.  In rio-calc
+    --nodata: nodata value.  In rio-info, rio-merge (different usages)
+    --photometric: photometric interpretation.  In rio-stack
+    --property: GeoJSON property to use as values for rasterize.  In rio-rasterize
+    -r, --res: output resolution.
+        In rio-info, rio-rasterize (different usages.  TODO: try to combine
+        usages, prefer rio-rasterize version)
+    --sampling: Inverse of sampling fraction.  In rio-shapes
+    --shape: shape (width, height) of band.  In rio-info
+    --src-crs: source CRS.
+        In rio-insp, rio-rasterize (different usages.  TODO: consolidate usages)
+    --stats: print raster stats.  In rio-inf
+    -t, --dtype: data type.  In rio-calc, rio-info (different usages)
+    --width: width of raster.  In rio-info
+    --with-nodata/--without-nodata: include nodata regions or not.  In rio-shapes.
+    -v, --tell-me-more, --verbose
+    --vfs: virtual file system.
 """
 
 import logging
@@ -51,26 +53,12 @@ import click
 
 import rasterio
 import rasterio.shutil
-from rasterio.path import parse_path, ParsedPath, UnparsedPath
+from rasterio._path import _parse_path, _UnparsedPath
 
 
 logger = logging.getLogger(__name__)
 
 
-class IgnoreOptionMarker(object):
-    """A marker for an option that is to be ignored.
-
-    For use in the case where `None` is a meaningful option value,
-    such as for nodata where `None` means "unset the nodata value."
-    """
-
-    def __repr__(self):
-        return 'IgnoreOption()'
-
-
-IgnoreOption = IgnoreOptionMarker()
-
-
 def _cb_key_val(ctx, param, value):
 
     """
@@ -110,9 +98,9 @@ def abspath_forward_slashes(path):
 def file_in_handler(ctx, param, value):
     """Normalize ordinary filesystem and VFS paths"""
     try:
-        path = parse_path(value)
+        path = _parse_path(value)
 
-        if isinstance(path, UnparsedPath):
+        if isinstance(path, _UnparsedPath):
 
             if os.path.exists(path.path) and rasterio.shutil.exists(value):
                 return abspath_forward_slashes(path.path)
@@ -127,14 +115,14 @@ def file_in_handler(ctx, param, value):
                 archive = abspath_forward_slashes(path.archive)
                 return "{}://{}!{}".format(path.scheme, archive, path.path)
             else:
-                raise IOError(
+                raise OSError(
                     "Input archive {} does not exist".format(path.archive))
 
         else:
             if os.path.exists(path.path) and rasterio.shutil.exists(value):
                 return abspath_forward_slashes(path.path)
             else:
-                raise IOError(
+                raise OSError(
                     "Input file {} does not exist".format(path.path))
 
     except Exception:
@@ -180,29 +168,36 @@ def like_handler(ctx, param, value):
 
 def nodata_handler(ctx, param, value):
     """Return a float or None"""
-    if value is None or value is IgnoreOption:
-        return value
-    elif value.lower() in ['null', 'nil', 'none', 'nada']:
+    if value is None or value.lower() in ["null", "nil", "none", "nada"]:
         return None
     else:
         try:
             return float(value)
         except (TypeError, ValueError):
             raise click.BadParameter(
-                "{!r} is not a number".format(value),
-                param=param, param_hint='nodata')
+                "{!r} is not a number".format(value), param=param, param_hint="nodata"
+            )
 
 
 def edit_nodata_handler(ctx, param, value):
     """Get nodata value from a template file or command line.
 
-    Expected values are 'like', 'null', a numeric value, 'nan', or
-    IgnoreOption. Anything else should raise BadParameter.
+    Expected values are 'like', 'null', a numeric value, 'nan', or None.
+
+    Returns
+    -------
+    float or None
+
+    Raises
+    ------
+    click.BadParameter
+
     """
-    if value == 'like' or value is IgnoreOption:
+    if value == "like" or value is None:
         retval = from_like_context(ctx, param, value)
         if retval is not None:
             return retval
+
     return nodata_handler(ctx, param, value)
 
 
@@ -319,7 +314,7 @@ creation_options = click.option(
     metavar='NAME=VALUE',
     multiple=True,
     callback=_cb_key_val,
-    help="Driver specific creation options."
+    help="Driver specific creation options. "
          "See the documentation for the selected output driver for "
          "more information.")
 
@@ -335,12 +330,20 @@ overwrite_opt = click.option(
     help="Always overwrite an existing output file.")
 
 nodata_opt = click.option(
-    '--nodata', callback=nodata_handler, default=None,
-    metavar='NUMBER|nan', help="Set a Nodata value.")
+    "--nodata",
+    callback=nodata_handler,
+    default=None,
+    metavar="NUMBER|nan",
+    help="Set a Nodata value.",
+)
 
 edit_nodata_opt = click.option(
-    '--nodata', callback=edit_nodata_handler, default=IgnoreOption,
-    metavar='NUMBER|nan|null', help="Modify the Nodata value.")
+    "--nodata",
+    callback=edit_nodata_handler,
+    default=None,
+    metavar="NUMBER|nan|null",
+    help="Modify the Nodata value.",
+)
 
 like_opt = click.option(
     '--like',
