@@ -6,8 +6,7 @@ import rasterio
 from rasterio._warp import WarpedVRTReaderBase
 from rasterio.dtypes import _gdal_typename
 from rasterio.enums import MaskFlags
-from rasterio.env import env_ctx_if_needed
-from rasterio.path import parse_path
+from rasterio._path import _parse_path
 from rasterio.transform import TransformMethodsMixin
 from rasterio.windows import WindowMethodsMixin
 
@@ -34,19 +33,19 @@ class WarpedVRT(WarpedVRTReaderBase, WindowMethodsMixin,
         default.
     crs : CRS or str, optional
         The coordinate reference system at the end of the warp
-        operation.  Default: the crs of `src_dataset`. dst_crs is
+        operation.  Default: the crs of `src_dataset`. dst_crs was
         a deprecated alias for this parameter.
     transform : Affine, optional
         The transform for the virtual dataset. Default: will be
         computed from the attributes of `src_dataset`. dst_transform
-        is a deprecated alias for this parameter.
+        was a deprecated alias for this parameter.
     height, width: int, optional
         The dimensions of the virtual dataset. Defaults: will be
         computed from the attributes of `src_dataset`. dst_height
-        and dst_width are deprecated alias for these parameters.
+        and dst_width were deprecated alias for these parameters.
     nodata : float, optional
         Nodata value for the virtual dataset. Default: the nodata
-        value of `src_dataset` or 0.0. dst_nodata is a deprecated
+        value of `src_dataset` or 0.0. dst_nodata was a deprecated
         alias for this parameter.
     resampling : Resampling, optional
         Warp resampling algorithm. Default: `Resampling.nearest`.
@@ -110,17 +109,16 @@ class WarpedVRT(WarpedVRTReaderBase, WindowMethodsMixin,
             self.closed and 'closed' or 'open', self.name, self.mode)
 
     def __enter__(self):
-        self._env = env_ctx_if_needed()
-        self._env.__enter__()
         self.start()
         return self
 
     def __exit__(self, *args, **kwargs):
-        self._env.__exit__()
-        self.close()
+        if not self._closed:
+            self.close()
 
     def __del__(self):
-        self.close()
+        if not self._closed:
+            self.close()
 
 
 def _boundless_vrt_doc(
@@ -176,7 +174,7 @@ def _boundless_vrt_doc(
         sourcefilename = ET.SubElement(complexsource, 'SourceFilename')
         sourcefilename.attrib['relativeToVRT'] = "0"
         sourcefilename.attrib["shared"] = "0"
-        sourcefilename.text = parse_path(src_dataset.name).as_vsi()
+        sourcefilename.text = _parse_path(src_dataset.name).as_vsi()
         sourceband = ET.SubElement(complexsource, 'SourceBand')
         sourceband.text = str(bidx)
         sourceproperties = ET.SubElement(complexsource, 'SourceProperties')
@@ -225,7 +223,7 @@ def _boundless_vrt_doc(
         sourcefilename = ET.SubElement(simplesource, 'SourceFilename')
         sourcefilename.attrib['relativeToVRT'] = "0"
         sourcefilename.attrib["shared"] = "0"
-        sourcefilename.text = parse_path(src_dataset.name).as_vsi()
+        sourcefilename.text = _parse_path(src_dataset.name).as_vsi()
 
         sourceband = ET.SubElement(simplesource, 'SourceBand')
         sourceband.text = 'mask,1'
