@@ -4,6 +4,7 @@
 import os
 import sys
 import textwrap
+from pathlib import Path
 
 import affine
 from click.testing import CliRunner
@@ -12,14 +13,11 @@ from pytest import fixture
 import pytest
 
 import rasterio
-from rasterio import Path
 from rasterio.enums import Resampling
 from rasterio.merge import merge
 from rasterio.rio.main import main_group
 from rasterio.transform import Affine
 
-from .conftest import requires_gdal22, gdal_version
-
 
 # Fixture to create test datasets within temporary directory
 @fixture(scope='function')
@@ -103,6 +101,21 @@ def test_data_dir_3(tmpdir):
     return tmpdir
 
 
+def test_rio_merge_dtype(test_data_dir_1, runner):
+    outputname = str(test_data_dir_1.join("merged.tif"))
+    inputs = [str(x) for x in test_data_dir_1.listdir()]
+    inputs.sort()
+
+    result = runner.invoke(
+        main_group, ["merge", "--dtype", "uint16"] + inputs + [outputname]
+    )
+    assert result.exit_code == 0
+    assert os.path.exists(outputname)
+
+    with rasterio.open(outputname) as out:
+        assert all(dt == "uint16" for dt in out.dtypes)
+
+
 def test_merge_with_colormap(test_data_dir_1, runner):
     outputname = str(test_data_dir_1.join('merged.tif'))
     inputs = [str(x) for x in test_data_dir_1.listdir()]
@@ -122,8 +135,6 @@ def test_merge_with_colormap(test_data_dir_1, runner):
         assert cmap[255] == (0, 0, 0, 255)
 
 
-@requires_gdal22(
-    reason="This test is sensitive to pixel values and requires GDAL 2.2+")
 def test_merge_with_nodata(test_data_dir_1, runner):
     outputname = str(test_data_dir_1.join('merged.tif'))
     inputs = [str(x) for x in test_data_dir_1.listdir()]
@@ -146,9 +157,11 @@ def test_merge_error(test_data_dir_1, runner):
     outputname = str(test_data_dir_1.join('merged.tif'))
     inputs = [str(x) for x in test_data_dir_1.listdir()]
     inputs.sort()
-    result = runner.invoke(
-        main_group, ['merge'] + inputs + [outputname] + ['--nodata', '-1'])
-    assert result.exit_code
+    with pytest.warns(UserWarning):
+        result = runner.invoke(
+            main_group, ["merge"] + inputs + [outputname] + ["--nodata", "-1"]
+        )
+        assert result.exit_code
 
 
 def test_merge_bidx(test_data_dir_3, runner):
@@ -165,8 +178,6 @@ def test_merge_bidx(test_data_dir_3, runner):
         assert out.count == 1
 
 
-@requires_gdal22(
-    reason="This test is sensitive to pixel values and requires GDAL 2.2+")
 def test_merge_without_nodata(test_data_dir_2, runner):
     outputname = str(test_data_dir_2.join('merged.tif'))
     inputs = [str(x) for x in test_data_dir_2.listdir()]
@@ -338,8 +349,6 @@ def test_data_dir_float(tmpdir):
     return tmpdir
 
 
-@requires_gdal22(
-    reason="This test is sensitive to pixel values and requires GDAL 2.2+")
 def test_merge_float(test_data_dir_float, runner):
     outputname = str(test_data_dir_float.join('merged.tif'))
     inputs = [str(x) for x in test_data_dir_float.listdir()]
@@ -440,8 +449,6 @@ def test_merge_tiny_output_opt(tiffs, runner):
         assert data[0][3][0] == 40
 
 
-@requires_gdal22(
-    reason="This test is sensitive to pixel values and requires GDAL 2.2+")
 @pytest.mark.xfail(sys.version_info < (3,),
                    reason="Test is sensitive to rounding behavior")
 def test_merge_tiny_res_bounds(tiffs, runner):
@@ -449,26 +456,38 @@ def test_merge_tiny_res_bounds(tiffs, runner):
     inputs = [str(x) for x in tiffs.listdir()]
     inputs.sort()
     result = runner.invoke(
-        main_group, ['merge'] + inputs + [outputname, '--res', 2, '--bounds', '1, 0, 5, 4'])
+        main_group,
+        ["merge"]
+        + inputs
+        + [outputname, "--res", 2, "--nodata", 0, "--bounds", "1, 0, 5, 4"],
+    )
     assert result.exit_code == 0
 
     # Output should be
-    # [[[0  90]
-    #   [0   0]]]
+    # [[[120  90]
+    #   [40    0]]]
 
     with rasterio.open(outputname) as src:
         data = src.read()
-        print(data)
-        assert data[0, 0, 0] == 0
+        assert data[0, 0, 0] == 120
         assert data[0, 0, 1] == 90
-        assert data[0, 1, 0] == 0
+        assert data[0, 1, 0] == 40
         assert data[0, 1, 1] == 0
 
 
-@pytest.mark.xfail(
-    gdal_version.major == 1,
-    reason="GDAL versions < 2 do not support data read/write with float sizes and offsets",
-)
+def test_merge_out_of_range_nodata(tiffs):
+    inputs = [
+        'tests/data/rgb1.tif',
+        'tests/data/rgb2.tif',
+        'tests/data/rgb3.tif',
+        'tests/data/rgb4.tif']
+    datasets = [rasterio.open(x) for x in inputs]
+    assert datasets[1].dtypes[0] == 'uint8'
+
+    with pytest.warns(UserWarning):
+        rv, transform = merge(datasets, nodata=9999)
+    assert not (rv == np.uint8(9999)).any()
+
 def test_merge_rgb(tmpdir, runner):
     """Get back original image"""
     outputname = str(tmpdir.join('merged.tif'))
@@ -481,7 +500,7 @@ def test_merge_rgb(tmpdir, runner):
     assert result.exit_code == 0
 
     with rasterio.open(outputname) as src:
-        assert [src.checksum(i) for i in src.indexes] == [33219, 35315, 45188]
+        assert [src.checksum(i) for i in src.indexes] == [25420, 29131, 37860]
 
 
 def test_merge_tiny_intres(tiffs):
@@ -491,13 +510,9 @@ def test_merge_tiny_intres(tiffs):
     merge(datasets, res=2)
 
 
-@pytest.mark.xfail(
-    gdal_version.major == 1,
-    reason="GDAL versions < 2 do not support data read/write with float sizes and offsets",
-)
 @pytest.mark.parametrize("precision", [[], ["--precision", "9"]])
 def test_merge_precision(tmpdir, precision):
-    """See https://github.com/mapbox/rasterio/issues/1837"""
+    """See https://github.com/rasterio/rasterio/issues/1837"""
     # TDOD move ascii grids to a fixture?
 
     expected = """\
@@ -642,9 +657,6 @@ def test_data_dir_resampling(tmpdir):
     return tmpdir
 
 
-@pytest.mark.xfail(
-    gdal_version.major == 1, reason="Mode resampling is unreliable for GDAL 1.11"
-)
 @pytest.mark.parametrize(
     "resampling",
     [resamp for resamp in Resampling if resamp < 7]
@@ -670,3 +682,21 @@ def test_merge_resampling(test_data_dir_resampling, resampling, runner):
         output_raster = dst.read()
 
     np.testing.assert_array_equal(output_raster, expected_raster)
+
+
+def test_merge_no_gap(tiffs, runner):
+    """This test fails before 1.3a1 using the original window rounding params (op=floor, pixel_precision-=0)."""
+    outputname = str(tiffs.join("merged.tif"))
+    inputs = [str(x) for x in tiffs.listdir()]
+    inputs.sort()
+    result = runner.invoke(
+        main_group,
+        ["merge"]
+        + inputs
+        + [outputname, "--res", 2 / 123, "--nodata", 0, "--bounds", "1, 0, 5, 4"],
+    )
+    assert result.exit_code == 0
+
+    with rasterio.open(outputname) as src:
+        data = src.read(1)
+        assert data[184, 61] != 0
