@@ -1,22 +1,17 @@
 """Unittests for $ rio warp"""
 
 
-import logging
 import os
-import sys
 
 import affine
 import numpy as np
 import pytest
 
 import rasterio
-from rasterio.env import GDALVersion
-from rasterio.warp import SUPPORTED_RESAMPLING, GDAL2_RESAMPLING
+from rasterio.warp import SUPPORTED_RESAMPLING
 from rasterio.rio import warp
 from rasterio.rio.main import main_group
 
-from .conftest import requires_gdal_lt_3
-
 
 def test_dst_crs_error(runner, tmpdir):
     """Invalid JSON is a bad parameter."""
@@ -541,25 +536,6 @@ def test_warp_reproject_check_invert_true(runner, tmpdir):
         assert output.shape == output2.shape
 
 
-@requires_gdal_lt_3
-def test_warp_reproject_check_invert_false(runner, tmpdir):
-    outputname = str(tmpdir.join('test.tif'))
-    output2name = str(tmpdir.join('test2.tif'))
-    srcname = 'tests/data/world.rgb.tif'
-
-    # default True
-    runner.invoke(main_group, [
-        'warp', srcname, outputname, '--dst-crs', 'EPSG:3759'])
-
-    # explicit False
-    runner.invoke(main_group, [
-        'warp', srcname, output2name, '--no-check-invert-proj',
-        '--dst-crs', 'EPSG:3759'])
-
-    with rasterio.open(outputname) as output, rasterio.open(output2name) as output2:
-        assert output.shape != output2.shape
-
-
 def test_warp_vrt_gcps(runner, tmpdir):
     """A VRT with GCPs can be warped."""
     srcname = 'tests/data/white-gemini-iv.vrt'
@@ -592,25 +568,6 @@ def test_warp_resampling(runner, path_rgb_byte_tif, tmpdir, method):
     assert result.exit_code == 0
 
 
-@pytest.mark.skipif(
-    GDALVersion.runtime().at_least('2.0'),
-    reason="Test only applicable to GDAL < 2.0")
-@pytest.mark.parametrize("method", GDAL2_RESAMPLING)
-def test_warp_resampling_not_yet_supported(
-        runner, path_rgb_byte_tif, tmpdir, method):
-    """Resampling methods not yet supported should fail with error"""
-
-    outputname = str(tmpdir.join('test.tif'))
-    result = runner.invoke(main_group, [
-        'warp', path_rgb_byte_tif, outputname,
-        '--dst-crs', 'epsg:3857',
-        '--resampling', method.name])
-
-    assert result.exit_code == 2
-    assert "Invalid value for" in result.output
-    assert "--resampling" in result.output
-
-
 def test_unrotate(runner, tmp_path):
     """rio-warp unrotates imagery by default, like gdalwarp"""
     outputname = tmp_path.joinpath("test.tif").as_posix()
@@ -620,3 +577,30 @@ def test_unrotate(runner, tmp_path):
     with rasterio.open(outputname) as src:
         assert src.transform.b == 0.0
         assert src.transform.d == 0.0
+
+
+@pytest.mark.parametrize(
+    "wotopt", ["--to", "--transformer-option", "--wo", "--warper-option"]
+)
+def test_coordinate_operation(runner, tmp_path, wotopt):
+    """Verify that transformer coordinate operations are activated."""
+    outputname = tmp_path.joinpath("test.tif").as_posix()
+    pipeline = "+proj=pipeline step inv proj=utm zone=11 ellps=clrk66 step proj=unitconvert xy_in=rad xy_out=deg step proj=axisswap order=2,1"
+    result = runner.invoke(
+        main_group,
+        [
+            "warp",
+            "--dst-crs",
+            "EPSG:4326",
+            "--resampling",
+            "cubic",
+            wotopt,
+            "coordinate_operation={}".format(pipeline),
+            "tests/data/byte.tif",
+            outputname,
+        ],
+    )
+    assert result.exit_code == 0
+
+    with rasterio.open(outputname) as src:
+        assert src.checksum(1) == 4705
