@@ -2,13 +2,10 @@ import pytest
 
 import rasterio
 
-from .conftest import requires_gdal21
-
 with rasterio.Env() as env:
     HAVE_NETCDF = 'NetCDF' in env.drivers().keys()
 
 
-@requires_gdal21(reason="NetCDF requires GDAL 2.1+")
 @pytest.mark.skipif(not HAVE_NETCDF,
                     reason="GDAL not compiled with NetCDF driver.")
 def test_subdatasets():
